<?php

namespace Drupal\content_reporting\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class ContentReportingSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_reporting_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['content_reporting.settings'];
  }

  /**
   * Build the configuration form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('content_reporting.settings');

    // Option to enable/disable GDPR tracking.
    $form['track_gdpr'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Track GDPR consent'),
      '#default_value' => $config->get('track_gdpr'),
      '#description' => $this->t('Enable tracking of GDPR consent.'),
    ];

    // Option to enable/disable click tracking.
    $form['track_clicks'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Track Clicks'),
      '#default_value' => $config->get('track_clicks'),
      '#description' => $this->t('Enable tracking of user clicks.'),
    ];

    // Option to enable/disable time spent tracking.
    $form['track_time_spent'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Track Time Spent'),
      '#default_value' => $config->get('track_time_spent'),
      '#description' => $this->t('Enable tracking of time spent on each page.'),
    ];

    // Option to enable/disable tracking for logged-in users.
    $form['track_logged_in_users'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Track Logged-in Users'),
      '#default_value' => $config->get('track_logged_in_users'),
      '#description' => $this->t('Enable tracking for logged-in users only.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('content_reporting.settings')
      ->set('track_gdpr', $form_state->getValue('track_gdpr'))
      ->set('track_clicks', $form_state->getValue('track_clicks'))
      ->set('track_time_spent', $form_state->getValue('track_time_spent'))
      ->set('track_logged_in_users', $form_state->getValue('track_logged_in_users'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}
